@@ -2,26 +2,22 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "পরিচিতজন",
-    "Name" : "নাম",
-    "Organization" : "প্রতিষ্ঠান",
-    "Title" : "শিরোনাম",
-    "Postal code" : "পোস্টাল কোড",
-    "City" : "শহর",
-    "State or province" : "রাজ্য কিংবা প্রদেশ",
-    "Country" : "দেশ",
-    "Address" : "ঠিকানা",
-    "Last name" : "নামের শেষাংশ",
-    "First name" : "নামের প্রথমাংশ ",
-    "Additional names" : "অতিরিক্ত নামসমূহ",
+    "Groups" : "গোষ্ঠীসমূহ",
     "New contact" : "নতুন ঠিকানা",
-    "Not grouped" : "দলবদ্ধ নয়",
+    "First name" : "নামের প্রথমাংশ ",
+    "Last name" : "নামের শেষাংশ",
     "Nickname" : "ছদ্মনাম",
+    "Additional names" : "অতিরিক্ত নামসমূহ",
     "Notes" : "নোট",
     "Website" : "ওয়েবসাইট",
     "Home" : "নিবাস",
     "Work" : "কর্মস্থল",
     "Other" : "অন্যান্য",
-    "Groups" : "গোষ্ঠীসমূহ",
+    "Address" : "ঠিকানা",
+    "City" : "শহর",
+    "State or province" : "রাজ্য কিংবা প্রদেশ",
+    "Postal code" : "পোস্টাল কোড",
+    "Country" : "দেশ",
     "Birthday" : "জন্মদিন",
     "Email" : "ইমেইল",
     "Instant messaging" : "তাৎক্ষণিক বার্তা",
@@ -29,7 +25,6 @@ OC.L10N.register(
     "Mobile" : "মোবাইল",
     "Fax" : "ফ্যাক্স",
     "Pager" : "পেজার",
-    "Voice" : "কন্ঠ",
-    "Settings" : "নিয়ামকসমূহ"
+    "Voice" : "কন্ঠ"
 },
 "nplurals=2; plural=(n != 1);");
