@@ -2,25 +2,21 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakti",
-    "Name" : "Ime",
-    "Organization" : "Organizacija",
-    "Title" : "Titula",
-    "Postal code" : "Poštanski broj",
-    "City" : "Grad",
-    "State or province" : "Savezna država ili pokrajina",
-    "Country" : "Država",
-    "Address" : "Adresa",
-    "Last name" : "Prezime",
-    "First name" : "Ime",
-    "Additional names" : "Dodatna imena",
+    "Groups" : "Grupe",
     "New contact" : "Novi kontakt",
-    "Not grouped" : "Nije grupirano",
+    "First name" : "Ime",
+    "Last name" : "Prezime",
     "Nickname" : "Nadimak",
+    "Additional names" : "Dodatna imena",
     "Website" : "Web-prezentacija",
     "Home" : "Kuća",
     "Work" : "Posao",
     "Other" : "Ostali",
-    "Groups" : "Grupe",
+    "Address" : "Adresa",
+    "City" : "Grad",
+    "State or province" : "Savezna država ili pokrajina",
+    "Postal code" : "Poštanski broj",
+    "Country" : "Država",
     "Birthday" : "Rođendan",
     "Email" : "E-pošta",
     "Instant messaging" : "Razmjena izravnih poruka",
@@ -28,7 +24,6 @@ OC.L10N.register(
     "Mobile" : "Mobitel",
     "Fax" : "Faks",
     "Pager" : "Dojavljivač",
-    "Voice" : "Glas",
-    "Settings" : "Postavke"
+    "Voice" : "Glas"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
