@@ -6,6 +6,7 @@ OC.L10N.register(
     "Details" : "Λεπτομέριες",
     "A contacts app for Nextcloud" : "Εφαρμογή επαφών για το Nextcloud",
     "Upload a new picture" : "Μεταφόρτωση νέας φωτογραφίας",
+    "Image is too big (max 1MB)." : "Η εικόνα είναι πολύ μεγάλη (μέγιστο 1MB).",
     "Loading" : "Γίνεται φόρτωση",
     "Name" : "Όνομα",
     "Company" : "Εταιρία",
@@ -61,6 +62,7 @@ OC.L10N.register(
     "Work pager" : "Βομβητής δουλειάς",
     "Social network" : "Κοινωνικό δίκτυο",
     "Relationship" : "Σχέση",
+    "Specify a relationship between you and the entity represented by this vCard." : "Καθορίστε μια σχέση μεταξύ σας και της οντότητας που αντιπροσωπεύεται από αυτήν την vCard.",
     "Spouse" : "Σύζηγος",
     "Child" : "Παιδί",
     "Mother" : "Μητέρα",
@@ -73,10 +75,14 @@ OC.L10N.register(
     "Colleague" : "Συνάδελφος",
     "Manager" : "Διευθυντής",
     "Assistant" : "Βοηθός",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Καθορίστε μια σχέση μεταξύ μιας άλλης οντότητας και της οντότητας που αντιπροσωπεύεται από αυτήν την vCard.",
     "Contact" : "Επαφή",
+    "Emergency" : "Επείγον",
     "Co-worker" : "Συνεργάτης",
     "Gender" : "Φύλλο",
     "Female" : "Θηλυκό",
-    "Male" : "Αρσενικό"
+    "Male" : "Αρσενικό",
+    "None" : "Κανένα",
+    "Unknown" : "Άγνωστο"
 },
 "nplurals=2; plural=(n != 1);");
