@@ -9,11 +9,15 @@ OC.L10N.register(
     "Title" : "Izenburua",
     "Download" : "Jaitsi",
     "Delete" : "Borratu",
+    "Addressbook" : "Helbide-liburua",
     "Groups" : "Taldeak",
     "New contact" : "Kontaktu berria",
     "Select type" : "Hautatu mota",
+    "Select Date" : "Hautatu data",
     "Add contact in group" : "Gehitu kontaktua taldera",
-    "Rename" : "Izena aldatu",
+    "No results" : "Emaitzarik ez",
+    "Rename" : "Aldatu izena",
+    "Copied" : "Kopiatuta",
     "Can not copy" : "Ezin da kopiatu",
     "Copy link" : "Esteka kopiatu",
     "Share with users or groups" : "Erabiltzaile edo taldeekin partekatu",
@@ -48,6 +52,7 @@ OC.L10N.register(
     "Phone" : "Telefonoa",
     "Mobile" : "Mugikorra",
     "Work mobile" : "Laneko mugikorra",
+    "Home mobile" : "Etxeko mugikorra",
     "Fax" : "Faxa",
     "Fax home" : "Etxeko Faxa",
     "Fax work" : "Laneko faxa",
