@@ -6,6 +6,8 @@ OC.L10N.register(
     "Details" : "詳細",
     "A contacts app for Nextcloud" : "Nextcloud の連絡先アプリ",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud の連絡先アプリは、 Nextcloud の CardDAV サーバーのユーザーインターフェースです。 さまざまなデバイスの連絡先を Nextcloud で簡単に同期し、オンラインで編集できます。\n\n*🚀**他の Nextcloud アプリケーションとの統合！**現在、メールとカレンダー - 今後の予定です。\n*🎉**誕生日を忘れないでください！**あなたの Nextcloud カレンダーで誕生日やその他の定期的なイベントを同期できます。\n*👥** 連絡先の共有！**あなたの友達や同僚とあなたの連絡先を共有したいですか？ 問題ない！\n*🙈**私たちは車輪を再発明していません！**偉大でオープンな SabreDAV ライブラリをベースにしています。",
+    "Copy to full name" : "フルネームをコピー",
+    "Omit year" : "年を省略する",
     "Add new property" : "新しいプロパティを追加する",
     "Choose property type" : "プロパティの種類を選択",
     "Add a new picture" : "画像を追加",
@@ -14,6 +16,8 @@ OC.L10N.register(
     "Delete picture" : "画像を削除",
     "Download picture" : "画像をダウンロード",
     "Image is too big (max 1MB)." : "画像容量が大きすぎます (最大1 MB)",
+    "Pick an avatar" : "アバターを選択",
+    "Error while processing the picture." : "画像の加工中にエラーが発生しました",
     "No contact selected" : "連絡先が選択されていません",
     "Select a contact on the list to begin" : "開始するには、リストの連絡先を選択してください",
     "Loading" : "読み込み中",
@@ -21,19 +25,26 @@ OC.L10N.register(
     "Company" : "会社",
     "Title" : "タイトル",
     "Download" : "ダウンロード",
+    "Generate QR Code" : "QRコードを生成",
     "Delete" : "削除",
-    "This contact is not yet synced. Edit it to save it to the server." : "この連絡先はまだ同期されていません。 それを編集してサーバーに保存して下さい。",
+    "This contact is not yet synced. Edit it to save it to the server." : "この連絡先はまだ同期されていません。 それを編集してサーバーに保存してください。",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
     "Addressbook" : "アドレス帳",
     "Groups" : "グループ",
     "New contact" : "新しい連絡先",
+    "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
+    "Deleting the contact in {countdown} seconds" : "{countdown}秒後に連絡先を削除します",
+    "Done importing {total} contacts into" : " {total} 数の連絡先をインポートしました",
     "Importing {total} contacts into" : "連絡先を {total} にインポートしています",
+    "No errors" : "エラーはありません",
     "Open your browser console for more details" : "詳細はブラウザコンソールを開きます",
+    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount}件の連絡先の誤り"],
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
     "Add contact in group" : "グループに連絡先を追加",
     "No results" : "該当なし",
+    "Last modified" : "最終更新日",
     "Select option" : "オプションを選択",
     "Rename" : "名前を変更",
     "Enabled" : "有効",
@@ -42,6 +53,8 @@ OC.L10N.register(
     "Can not copy" : "コピーできません",
     "Copy link" : "リンクをコピー",
     "Enabled toggle of addressbook was not successful." : "アドレス帳の有効なトグルが成功しませんでした。",
+    "This will delete the addressbook and every contacts within it" : "アドレス帳とすべての連絡先が削除されます。",
+    "Delete {addressbook} ?" : "{アドレス帳}を削除しますか？",
     "Deletion of addressbook was not successful." : "アドレス帳の削除に失敗しました。",
     "Renaming of addressbook was not successful." : "アドレス帳の名前を変更できませんでした。",
     "Addressbook copied to clipboard" : "アドレス帳をクリップボードにコピー",
@@ -61,6 +74,8 @@ OC.L10N.register(
     "Last name" : "姓",
     "Display name" : "表示名",
     "Sort by {sorting}" : "{sorting} で整列",
+    "Not grouped" : "グループ化されていません",
+    "Unable to create the contact." : "連絡先を追加できません。",
     "Contact not found" : "連絡先がありません",
     "Nickname" : "ニックネーム",
     "Detailed name" : "詳細名",
@@ -82,6 +97,7 @@ OC.L10N.register(
     "Country" : "国名",
     "Birthday" : "誕生日",
     "Anniversary" : "記念日",
+    "The date of marriage, or equivalent, of this contact" : "この連絡先の結婚日か、それに相当する日",
     "Date of death" : "命日",
     "Email" : "メール",
     "Instant messaging" : "インスタントメッセージ",
@@ -121,6 +137,11 @@ OC.L10N.register(
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
-    "An error occurred" : "エラーが発生しました"
+    "None" : "なし",
+    "Unknown" : "不明",
+    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
+    "An error occurred" : "エラーが発生しました",
+    "Your web browser is out of date" : "ウェブブラウザが古いです",
+    "This application is not compatible with Internet Explorer" : "このアプリはInternet Explorerと互換性がありません"
 },
 "nplurals=1; plural=0;");
