@@ -2,33 +2,24 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Контакти",
-    "Address book name" : "Име на адресната книга",
-    "No contacts in here" : "Тука нема контакти",
-    "Name" : "Име",
-    "Organization" : "Организација",
-    "Title" : "Наслов",
-    "No search result for {query}" : "Нема резултати од пребарувањето за {query}",
     "All contacts" : "Сите контакти",
-    "Postal code" : "Поштенски број",
-    "City" : "Град",
-    "State or province" : "Град или провинција",
-    "Country" : "Држава",
-    "Address" : "Адреса",
-    "(new group)" : "(нова група)",
-    "Last name" : "Презиме",
-    "First name" : "Име",
-    "Additional names" : "Дополнителни имиња",
+    "Groups" : "Групи",
     "New contact" : "Нов контакт",
-    "Not grouped" : "Не групирани",
-    "{addressbook} shared by {owner}" : "{addressbook} споделено од {owner}",
+    "First name" : "Име",
+    "Last name" : "Презиме",
     "Nickname" : "Прекар",
+    "Additional names" : "Дополнителни имиња",
     "Notes" : "Белешки",
     "Website" : "Веб сајт",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Дома",
     "Work" : "Работа",
     "Other" : "Останато",
-    "Groups" : "Групи",
+    "Address" : "Адреса",
+    "City" : "Град",
+    "State or province" : "Град или провинција",
+    "Postal code" : "Поштенски број",
+    "Country" : "Држава",
     "Birthday" : "Роденден",
     "Email" : "Е-пошта",
     "Instant messaging" : "Инстантни пораки",
@@ -38,7 +29,6 @@ OC.L10N.register(
     "Fax home" : "Fax дома",
     "Fax work" : "Fax на работа",
     "Pager" : "Пејџер",
-    "Voice" : "Глас",
-    "Settings" : "Подесувања"
+    "Voice" : "Глас"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
