@@ -2,31 +2,26 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontaktar",
-    "Name" : "Namn",
-    "Organization" : "Organisasjon",
-    "Title" : "Tittel",
-    "Postal code" : "Postkode",
-    "City" : "Stad",
-    "State or province" : "Fylke, stat eller region",
-    "Country" : "Land",
-    "Address" : "Adresse",
-    "Last name" : "Etternamn",
+    "Groups" : "Grupper",
     "First name" : "Fornamn",
-    "Additional names" : "Andre namn",
-    "Not grouped" : "Ikkje gruppert",
+    "Last name" : "Etternamn",
     "Nickname" : "Kallenamn",
+    "Additional names" : "Andre namn",
     "Notes" : "Notat",
     "Home" : "Heime",
     "Work" : "Arbeid",
     "Other" : "Anna",
-    "Groups" : "Grupper",
+    "Address" : "Adresse",
+    "City" : "Stad",
+    "State or province" : "Fylke, stat eller region",
+    "Postal code" : "Postkode",
+    "Country" : "Land",
     "Birthday" : "Bursdag",
     "Email" : "E-post",
     "Phone" : "Telefonnummer",
     "Mobile" : "Mobil",
     "Fax" : "Faks",
     "Pager" : "Personsøkjar",
-    "Voice" : "Tale",
-    "Settings" : "Innstillingar"
+    "Voice" : "Tale"
 },
 "nplurals=2; plural=(n != 1);");
