@@ -2,29 +2,24 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contactes",
-    "Name" : "Nom",
-    "Organization" : "Societat",
-    "Title" : "Títol",
     "All contacts" : "Totes los contactes",
-    "Postal code" : "Còde postal",
-    "City" : "Vila",
-    "State or province" : "Estat o region",
-    "Country" : "País",
-    "Address" : "Adreça",
-    "(new group)" : "(grop novèl)",
-    "Last name" : "Nom",
-    "First name" : "Prenom",
-    "Additional names" : "Noms suplementaris",
+    "Groups" : "Gropes",
     "New contact" : "Contacte novèl",
-    "Not grouped" : "Pas gropats",
+    "First name" : "Prenom",
+    "Last name" : "Nom",
     "Nickname" : "Escais",
+    "Additional names" : "Noms suplementaris",
     "Notes" : "Nòtas",
     "Website" : "Site web",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Domicili",
     "Work" : "Professional(a)",
     "Other" : "Autre",
-    "Groups" : "Gropes",
+    "Address" : "Adreça",
+    "City" : "Vila",
+    "State or province" : "Estat o region",
+    "Postal code" : "Còde postal",
+    "Country" : "País",
     "Birthday" : "Anniversari",
     "Email" : "Adreça corrièl",
     "Instant messaging" : "Messatjariá instantanèa",
@@ -32,7 +27,6 @@ OC.L10N.register(
     "Mobile" : "Mobil",
     "Fax" : "Fax",
     "Pager" : "Messatgièr",
-    "Voice" : "Votz",
-    "Settings" : "Paramètres"
+    "Voice" : "Votz"
 },
 "nplurals=2; plural=(n > 1);");
