@@ -23,6 +23,7 @@ OC.L10N.register(
     "Name" : "Namn",
     "Company" : "Företag",
     "Title" : "Titel",
+    "This contact was broken and received a fix. Please review the content and click here to save it." : "Denna kontakt var felaktig och åtgärdades. Granska innehållet och klicka här för att spara det.",
     "Download" : "Ladda ned",
     "Generate QR Code" : "Generera QR-kod",
     "Delete" : "Radera",
@@ -139,6 +140,8 @@ OC.L10N.register(
     "Male" : "Man",
     "None" : "Ingen",
     "Unknown" : "Okänd",
+    "Timezone" : "Tidszon",
+    "Spoken languages" : "Talade språk",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunde inte läsas","{failed} kontakter kunde inte läsas"],
     "An error occurred" : "Ett fel uppstod",
     "Your web browser is out of date" : "Din webbläsare är för gammal",
