@@ -24,6 +24,7 @@ OC.L10N.register(
     "Name" : "名称",
     "Company" : "公司",
     "Title" : "头衔",
+    "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人已损坏但接收到了一个修复。请查看内容并点击这里以保存它。",
     "Download" : "下载",
     "Generate QR Code" : "生成二维码",
     "Delete" : "删除",
@@ -84,6 +85,7 @@ OC.L10N.register(
     "Suffix" : "后缀",
     "Notes" : "说明",
     "Website" : "网站",
+    "Location" : "地点",
     "Federated Cloud ID" : "联合云 ID",
     "Home" : "家庭",
     "Work" : "工作",
@@ -139,6 +141,8 @@ OC.L10N.register(
     "Male" : "男性",
     "None" : "无",
     "Unknown" : "未知",
+    "Timezone" : "时区",
+    "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 联系人读取失败"],
     "An error occurred" : "发生错误",
     "Your web browser is out of date" : "您的浏览器版本太旧",
